@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "typst-preview" "1.0.0"
+(define-package "typst-preview" "20251110.824"
   "Live preview of typst."
   '((emacs     "28.1")
     (websocket "1.15")
